@@ -6,6 +6,7 @@ to create release notes.
 import argparse
 import os
 import re
+import sys
 
 import requests
 from datetime import datetime, timedelta
@@ -234,12 +235,6 @@ def main(args=None):
     else:
         g = Github()
 
-    headers = {}
-    if args.github_access_token:
-        headers = {"Authorization": f"token {args.github_access_token}"}
-    else:
-        print("No GitHub access token provided. Will fail to access private repos.")
-
     # Get GitHub Repository
     git = Repo(search_parent_directories=True)
     if args.repo:
@@ -337,13 +332,27 @@ def main(args=None):
     if hasattr(args, "to_date") and args.to_date is not None:
         stop_date = datetime.strptime(args.to_date, "%Y-%m-%d")
 
+    # TODO: Revisit this whole logic to adopt proper githubapi requests
+    # instead of this `branch_commits` approach that is not compatible with private repos. See ticket PXP-7714
+    # Skipping private repos for now
+    private_check = requests.get(
+        "https://api.github.com/repos/%s" % (uri),
+        headers=headers,
+    )
+    resp.raise_for_status()
+    private_check_json = private_check.json()
+    if private_check_json["private"] == True:
+        print("Cannot access private repos at the moment - exiting")
+        sys.exit(0)
+
     for commit in repo.get_commits(since=start_date, until=stop_date):
         # https://platform.github.community/t/get-pull-request-associated-with-merge-commit/6936
         # https://github.blog/2014-10-13-linking-merged-pull-requests-from-commits/
-        # We are not using the search API because its rate limit is too low
+        # We are not using the search API because its rate limit is too low.
+        # This doesn't work for private repos, and we can't attach headers
+        # because it's not a GitHub API endpoint. See ticket PXP-7714
         resp = requests.get(
-            "https://github.com/%s/branch_commits/%s" % (uri, commit.sha),
-            headers=headers,
+            "https://github.com/%s/branch_commits/%s" % (uri, commit.sha)
         )
         resp.raise_for_status()
         prs = _GITHUB_PR.findall(resp.text)
